translate.storage.cpo.po_error_handler

Package translate :: Package storage :: Module cpo :: Class po_error_handler |
[hide private]
[frames] | no frames]

# Class po_error_handler

source code

Class Variables | [hide private]
| _fields_ = `[('error', CFUNCTYPE(None, c_int, c_int, STRING)), `...``

Class Variable Details | [hide private]

  ### _fields_ Value:
      [('error', CFUNCTYPE(None, c_int, c_int, STRING)), ('error_at_line', C
      FUNCTYPE(None, c_int, c_int, STRING, c_uint, STRING)), ('multiline_war
      ning', CFUNCTYPE(None, STRING, STRING)), ('multiline_error', CFUNCTYPE
      (None, STRING, STRING)),]